@@ -16,6 +16,7 @@
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -36,8 +37,8 @@ typedef struct Stack {
 } Stack;
 
 #define STACK_DEF
-#include "cards.h"
 #include "imagelib.h"
+#include "cards.h"
 
 static Picture **fronts=0;
 static Picture *back=0;
@@ -550,6 +551,8 @@ stack_move_cards(Stack *src, int n, Stack *dest)
 void
 stack_flip_card(Stack *src, Stack *dest)
 {
+  if (src->num_cards < 1)
+    return;
   stack_note_undo(src, src->num_cards-1, dest);
   doing_undo = 1;
   if (src != dest)
@@ -589,6 +592,8 @@ stack_note_undo(Stack *src, int n, Stack *dest)
     else
       undo = (Undo *)malloc(max_undo * sizeof(Undo));
   }
+  if (src->num_cards < 1)
+    return;
   undo[num_undo].src = src;
   undo[num_undo].dest = dest;
   undo[num_undo].count = stack_count_cards(src) - n + 1;
