@@ -29,9 +29,10 @@
 #undef CD
 #define CD
 
-#include "cards.h"
 #include "imagelib.h"
+#include "cards.h"
 #include "xwin.h"
+#include "funcs.h"
 
 #define TRACE_EVENTS		0
 #define TRACE_PICTURES		0
@@ -62,10 +63,29 @@ static OptionDesc ace_options[] = {
   { 0, 0, 0 }
 };
 
+static FunctionMapping flist[] = {
+  { "click", &click_cb },
+  { "drag", &drag_cb },
+  { "redraw", &redraw_cb },
+  { "init", &init_cb },
+  { "drop", &drop_cb },
+  { "key", &key_cb },
+  { "resize", &resize_cb },
+  { "double_click", &double_click_cb },
+  { 0, 0 }
+};
+
+extern image_list cards_imagelib[];
+static image_list card_images[];
+
 void
-init_ace(int argc, char **argv)
+init_ace(int argc, char **argv, FunctionMapping *funcs)
 {
   int i = 0, o, a, errors=0;
+
+  register_imagelib(cards_imagelib);
+  register_imagelib(card_images);
+
   if (app_options)
     options[i++] = app_options;
   if (xwin_options)
@@ -73,6 +93,11 @@ init_ace(int argc, char **argv)
   options[i++] = ace_options;
   options[i++] = 0;
 
+  for (i=0; funcs[i].name; i++)
+    for (a=0; flist[a].name; a++)
+      if (strcmp(funcs[i].name, flist[a].name) == 0)
+	*(void **)flist[a].function = funcs[i].function;
+
   for (a=1; a<argc; a++)
     {
       int found = 0;
@@ -118,13 +143,13 @@ init_ace(int argc, char **argv)
     argv[i++] = argv[a++];
   argv[i] = 0;
 
-  xwin_init(argc, argv);
+  if (xwin_init(argc, argv))
+    exit(1);
 }
 
 void
 init_table(int width, int height)
 {
-  need_imglib_cards();
 
   if (width > display_width)
     width = display_width;
@@ -291,7 +316,7 @@ maybe_init()
       initted = 1;
       flush();
       graphics_disabled = 1;
-      init();
+      init_cb();
       graphics_disabled = 0;
 #if TRACE_EVENTS
       printf(" - done init\n");
@@ -328,7 +353,7 @@ table_loop()
 	else
 	  {
 	    graphics_disabled = 1;
-	    resize(event.w, event.h);
+	    resize_cb(event.w, event.h);
 	    graphics_disabled = 0;
 	    if (no_resize)
 	      xwin_fixed_size(table_width, table_height);
@@ -339,7 +364,7 @@ table_loop()
 		if (first_expose)
 		  {
 		    clear (0, 0, table_width, table_height);
-		    redraw();
+		    redraw_cb();
 		  }
 	      }
 	  }
@@ -369,7 +394,7 @@ table_loop()
 	if (help_is_showing)
 	  help_redraw();
 	else
-	  redraw();
+	  redraw_cb();
 	redraw_centered_pic();
 	xwin_noclip();
 #if TRACE_EVENTS
@@ -392,12 +417,12 @@ table_loop()
 	  }
 	else if (event.time - dct < DBLCLICK_TIME)
 	  {
-	    double_click(event.x, event.y, event.button);
+	    double_click_cb(event.x, event.y, event.button);
 	    dct -= DBLCLICK_TIME;
 	  }
 	else
 	  {
-	    click(event.x, event.y, click_button);
+	    click_cb(event.x, event.y, click_button);
 	    dcx = event.x;
 	    dcy = event.y;
 	    dct = event.time;
@@ -414,7 +439,7 @@ table_loop()
 #if TRACE_EVENTS
 	    printf("drag: %d,%d %d\n", event.x, event.y, click_button);
 #endif
-	    drag(event.x, event.y, click_button);
+	    drag_cb(event.x, event.y, click_button);
 	  }
 	break;
 
@@ -426,7 +451,7 @@ table_loop()
 	printf("drop: %d,%d\n", event.x, event.y);
 #endif
 	if (!help_is_showing)
-	  drop(event.x, event.y, click_button);
+	  drop_cb(event.x, event.y, click_button);
 	break;
 
       case ev_keypress:
@@ -435,7 +460,7 @@ table_loop()
 	if (help_is_showing)
 	  help_key(event.key, event.x, event.y);
 	else
-	  key(event.key, event.x, event.y);
+	  key_cb(event.key, event.x, event.y);
 	break;
 
       case ev_quit:
@@ -539,7 +564,7 @@ invalidate_sub(int x, int y, int w, int h)
   if (help_is_showing)
     help_redraw();
   else
-    redraw();
+    redraw_cb();
   redraw_centered_pic();
   xwin_noclip();
 }
@@ -587,7 +612,7 @@ invalidate_nc(int x, int y, int w, int h)
   if (help_is_showing)
     help_redraw();
   else
-    redraw();
+    redraw_cb();
   redraw_centered_pic();
 #if TRACE_INVALIDATE
   printf(" - done invalidate\n");
@@ -973,7 +998,7 @@ back_synth(image_list *list, int type, int width, int height)
   return rv;
 }
 
-image_list card_images[] = {
+static image_list card_images[] = {
   { "ac", 1, 1, {0,0,0}, 0, card_synth, 0 },
   { "ad", 1, 1, {0,0,0}, 0, card_synth, 0 },
   { "as", 1, 1, {0,0,0}, 0, card_synth, 0 },
@@ -1031,5 +1056,3 @@ image_list card_images[] = {
   { 0 }
 };
 
-REGISTER_IMAGE_LIBRARY(card_images)
-
